@@ -447,6 +447,20 @@ class KeycloakAdmin:
         groups = self.get_groups(query)
         return next((group["id"] for group in groups if group["name"] == groupname), None)
 
+    def update_group(self, group_id, payload):
+        """
+        Update group by id.
+
+        :param group_id: id of group
+        :param payload: GroupRepresentation
+        http://www.keycloak.org/docs-api/3.3/rest-api/#_grouprepresentation
+
+        :return: Keycloak server response
+        """
+        params_path = {"realm-name": self.realm_name, "id": group_id}
+        data_raw = self.connection.raw_put(URL_ADMIN_GROUP.format(**params_path), data=json.dumps(payload))
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
+    
     def get_subgroups(self, group, path):
         """
         Utility function to iterate through nested group structures
